==> spring-boot-ext-1.2.279.1-sources.jar: cn/com/duibaboot/ext/autoconfigure/flowreplay/GuavaCacheFlowReplaySpan.java <==
package cn.com.duibaboot.ext.autoconfigure.flowreplay;

import cn.com.duiba.wolf.utils.UUIDUtils;
import cn.com.duibaboot.ext.autoconfigure.flowreplay.serializer.KryoSerializer;

import java.lang.reflect.Method;

/**
 * guava缓存类型的span
 * Created by guoyanfei .
 * 2019-04-15 .
 */
public class GuavaCacheFlowReplaySpan extends FlowReplaySpan {

    private static final long serialVersionUID = 2104265694610835781L;

    /**
     * 方法名称
     */
    private String methodName;

    /**
     * 参数类型数组
     */
    private String[] parameterTypes;

    /**
     * 参数值数组
     */
    private byte[] parameterValues;

    /**
     * 返回值
     */
    private byte[] returnValue;

    @Override
    public SpanType getSpanType() {
        return SpanType.GUAVA_CACHE;
    }

    /**
     * 创建span
     * @param method
     * @param allArguments
     * @param argumentsTypes
     * @param ret
     * @return
     */
    public static GuavaCacheFlowReplaySpan createSpan(Method method, Object[] allArguments, Class<?>[] argumentsTypes, Object ret) {
        String[] parameterTypes = null;
        if (argumentsTypes.length > 0) {
            parameterTypes = new String[argumentsTypes.length];
            for (int i = 0; i < argumentsTypes.length; i++) {
                parameterTypes[i] = argumentsTypes[i].getName();
            }
        }
        GuavaCacheFlowReplaySpan span = new GuavaCacheFlowReplaySpan();
        span.setSpanId(UUIDUtils.createUUID());
        span.methodName = method.getName();
        span.parameterTypes = parameterTypes;
        span.parameterValues = KryoSerializer.serialize(allArguments);
        span.returnValue = KryoSerializer.serialize(ret);
        return span;
    }

    public String getMethodName() {
        return methodName;
    }

    public String[] getParameterTypes() {
        return parameterTypes;
    }

    public Object[] getParameterValues() {
        return (Object[]) KryoSerializer.deserialize(parameterValues);
    }

    public Object getReturnValue() {
        return KryoSerializer.deserialize(returnValue);
    }
}

==> spring-boot-ext-1.2.280.13-sources.jar: cn/com/duibaboot/ext/autoconfigure/flowreplay/GuavaCacheFlowReplaySpan.java <==
package cn.com.duibaboot.ext.autoconfigure.flowreplay;

import cn.com.duiba.wolf.utils.UUIDUtils;
import cn.com.duibaboot.ext.autoconfigure.flowreplay.serializer.KryoSerializer;

import java.lang.reflect.Method;

/**
 * guava缓存类型的span
 * Created by guoyanfei .
 * 2019-04-15 .
 */
public class GuavaCacheFlowReplaySpan extends FlowReplaySpan {

    private static final long serialVersionUID = 2104265694610835781L;

    /**
     * 方法名称
     */
    private String methodName;

    /**
     * 参数类型数组
     */
    private String[] parameterTypes;

    /**
     * 参数值数组
     */
    private byte[] parameterValues;

    /**
     * 返回值
     */
    private byte[] returnValue;

    @Override
    public SpanType getSpanType() {
        return SpanType.GUAVA_CACHE;
    }

    /**
     * 创建span
     * @param method
     * @param allArguments
     * @param argumentsTypes
     * @param ret
     * @return
     */
    public static GuavaCacheFlowReplaySpan createSpan(Method method, Object[] allArguments, Class<?>[] argumentsTypes, Object ret) {
        String[] parameterTypes = null;
        Class<?>[] argumentsTypesTemp = customizeArgumentsTypes(method, argumentsTypes);
        if (argumentsTypesTemp.length > 0) {
            parameterTypes = new String[argumentsTypesTemp.length];
            for (int i = 0; i < argumentsTypesTemp.length; i++) {
                parameterTypes[i] = argumentsTypesTemp[i].getName();
            }
        }
        GuavaCacheFlowReplaySpan span = new GuavaCacheFlowReplaySpan();
        span.setSpanId(UUIDUtils.createUUID());
        span.methodName = method.getName();
        span.parameterTypes = parameterTypes;
        span.parameterValues = KryoSerializer.serialize(customizeParameterValues(method, allArguments));
        span.returnValue = KryoSerializer.serialize(ret);
        return span;
    }

    public static Class<?>[] customizeArgumentsTypes(Method method, Class<?>[] argumentsTypes) {
        if ("get".equals(method.getName())) {
            return new Class<?>[] { argumentsTypes[0] };
        }
        return argumentsTypes;
    }

    public static Object[] customizeParameterValues(Method method, Object[] parameterValues) {
        if ("get".equals(method.getName())) {
            return new Object[] { parameterValues[0] };
        }
        return parameterValues;

    }

    public String getMethodName() {
        return methodName;
    }

    public String[] getParameterTypes() {
        return parameterTypes;
    }

    public Object[] getParameterValues() {
        return (Object[]) KryoSerializer.deserialize(parameterValues);
    }

    public Object getReturnValue() {
        return KryoSerializer.deserialize(returnValue);
    }
}
